//
//  LocationViewController.m
//  iPickUApp
//
//  Created by Giuseppe Macrì on 7/16/13.
//  Copyright (c) 2013 Giuseppe Macrì. All rights reserved.
//

#import "LocationViewController.h"
#import "City.h"
#import "Location.h"

@interface LocationViewController ()

@property (weak, nonatomic) NSArray *cities;
@property (weak, nonatomic) NSMutableDictionary *locations;

@property (weak, nonatomic) Location *locationToAvoid;

@end

@implementation LocationViewController

@synthesize delegate;

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
//        [self initParseClass];
    }
    return self;
}

- (id)initWithCoder:(NSCoder *)aCoder {
    self = [super initWithCoder:aCoder];
    if (self) {
        self.cities = [[ParseCommunication parseCommunication] cities];
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    // Uncomment the following line to preserve selection between presentations.
    self.clearsSelectionOnViewWillAppear = NO;
 
    if (self.isOrigin) {
        self.locations = [[ParseCommunication parseCommunication] origins];
        self.locationToAvoid = nil;
    } else {
        self.locations = [[ParseCommunication parseCommunication] destinations];
        self.locationToAvoid = [self.delegate pickUpLocation];
    }
    
    
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
//    self.navigationItem.rightBarButtonItem = self.editButtonItem;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return [self.cities count];
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    City *city = [self.cities objectAtIndex:section];
    NSArray *stations = [self.locations objectForKey:city.name];
    return [stations count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = LOCATION_CELL;
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier forIndexPath:indexPath];
    
    // Configure the cell...
    if (!cell) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:LOCATION_CELL];
    }
    
    City *city = [self.cities objectAtIndex:indexPath.section];
    NSArray *stations = [self.locations objectForKey:city.name];
    Location *location = [stations objectAtIndex:indexPath.row];
    
    cell.textLabel.text = location.station;
    cell.detailTextLabel.text = location.city.name;
    
    if (location && [location.objectId isEqualToString:self.locationToAvoid.objectId]) {
        cell.userInteractionEnabled = NO;
        cell.backgroundColor = [UIColor greenColor];
    }
    
    
    return cell;
}

- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section
{
    City *city = [self.cities objectAtIndex:section];
    return city.name;
}

/*
// Override to support conditional editing of the table view.
- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the specified item to be editable.
    return YES;
}
*/

/*
// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        // Delete the row from the data source
        [tableView deleteRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationFade];
    }   
    else if (editingStyle == UITableViewCellEditingStyleInsert) {
        // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
    }   
}
*/

/*
// Override to support rearranging the table view.
- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath
{
}
*/

/*
// Override to support conditional rearranging of the table view.
- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the item to be re-orderable.
    return YES;
}
*/

#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
//    UITableViewCell *cell = [self.tableView cellForRowAtIndexPath:indexPath];
    
    City *city = [self.cities objectAtIndex:indexPath.section];
    NSArray *stations = [self.locations objectForKey:city.name];
    Location *selectedLocation = [stations objectAtIndex:indexPath.row];
    if (self.isOrigin) {
        [self.delegate setPickUpLocation:selectedLocation];
    } else {
        [self.delegate setDropOffLocation:selectedLocation];
    }
    
    // set delegate location using title
    [self.navigationController popViewControllerAnimated:YES];
    
}

@end
